# twang

<!-- [![Twang](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/michaelhball/twang/main/assets/badge/v1.json)](https://github.com/michaelhball/twang) -->
[![image](https://img.shields.io/pypi/v/twang.svg)](https://pypi.python.org/pypi/twang)
[![image](https://img.shields.io/pypi/l/twang.svg)](https://pypi.python.org/pypi/twang)
[![image](https://img.shields.io/pypi/pyversions/twang.svg)](https://pypi.python.org/pypi/twang)

Machine learning tools for guitarists.
